import 'package:cached_network_image/cached_network_image.dart';
import 'package:dart_blocks/dart_blocks/nuntio_client.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nuntio_blocks/block_user.pb.dart';

import 'button_card/button_card.dart';

class UserProfile extends StatefulWidget {
  UserProfile({
    Key? key,
    required this.profileTitle,
    required this.changePasswordText,
    required this.changeEmailText,
    required this.logoutText,
  }) : super(key: key);

  final Widget profileTitle;
  final Widget changePasswordText;
  final Widget changeEmailText;
  final Widget logoutText;

  @override
  State<UserProfile> createState() => _UserProfileState();
}

class _UserProfileState extends State<UserProfile> {
  // This widget is the root of your application.
  String name = "";
  late final Future<User> currentUserFuture;

  _UserProfileState() {
    currentUserFuture = NuntioClient.userBlock.getCurrentUser();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<User>(
      future: currentUserFuture,
      builder: (BuildContext context, AsyncSnapshot<User> snapshot) {
        switch (snapshot.connectionState) {
          case ConnectionState.waiting:
            return const Center(
              child: CupertinoActivityIndicator(),
            );
          case ConnectionState.done:
            return Padding(
              padding: const EdgeInsets.only(left: 10, right: 10),
              child: Column(
                children: [
                  const SizedBox(
                    height: 10,
                  ),
                  Container(
                    width: 80.0,
                    height: 80.0,
                    child: CachedNetworkImage(
                      imageUrl: (snapshot.data ?? User()).image,
                      imageBuilder: (context, imageProvider) => Container(
                        width: 80.0,
                        height: 80.0,
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          image: DecorationImage(
                            image: imageProvider,
                            fit: BoxFit.cover,
                          ),
                        ),
                      ),
                      placeholder: (context, url) =>
                          CupertinoActivityIndicator(),
                      errorWidget: (context, url, error) => CircleAvatar(
                        backgroundColor: CupertinoColors.white,
                        radius: 40,
                        child: Icon(
                          CupertinoIcons.profile_circled,
                          color: CupertinoColors.lightBackgroundGray,
                          size: 70,
                        ),
                      ),
                    ),
                  ),
                  const SizedBox(
                    height: 20,
                  ),
                  SizedBox(
                    width: 200,
                    child: Text(
                      "oscar@softcorp.io",
                      style: Theme.of(context)
                          .textTheme
                          .titleLarge
                          ?.copyWith(color: CupertinoColors.black),
                      overflow: TextOverflow.ellipsis,
                      textAlign: TextAlign.center,
                      maxLines: 2,
                    ),
                  ),
                  const SizedBox(
                    height: 20,
                  ),
                  ButtonCard(
                    onClick: () {
                      print("hello");
                    },
                    text: widget.changeEmailText,
                  ),
                  const SizedBox(
                    height: 10,
                  ),
                  ButtonCard(
                    onClick: () {
                      print("hello");
                    },
                    text: widget.changePasswordText,
                  ),
                  const SizedBox(
                    height: 10,
                  ),
                  ButtonCard(
                    onClick: () {
                      NuntioClient.userBlock.logout().then((value) {
                        Navigator.of(context)
                            .popUntil((route) => route.isFirst);
                      });
                    },
                    text: widget.logoutText,
                  ),
                ],
              ),
            );
          default:
            return Text("Error");
        }
      },
    );
  }
}
